# Welcome to ortho_modificator


[![image](https://img.shields.io/pypi/v/ortho_modificator.svg)](https://pypi.python.org/pypi/ortho_modificator)


**A python package for Orthophoto analysis and modification.**


-   Free software: MIT License
-   Documentation: <https://gismam.github.io/ortho_modificator>


## Features

-   Create interactive maps
-   Process geospatial data

## Usage

```python
import geodev
import os
```